import pandas as pd
import json
import os
from pathlib import Path

from utils.documents_to_database import documents_to_database
from utils.convert_encoding_meta import convert_encoding_meta

## %% Obtenir le répertoire du fichier courant
# Obtenir le répertoire du fichier courant
try:
    # Ceci fonctionnera lors de l'exécution en tant que script
    script_dir = Path(__file__).parent.parent
except NameError:
    # Ceci fonctionnera dans des environnements interactifs
    script_dir = Path().absolute()

project_root = script_dir
fb_data_path = os.path.join(project_root, 'import_data', 'data', 'Facebook', 'posts', 'your_uncategorized_photos.json')

## %% Lire et parser le fichier JSON des photos Facebook non catégorisées
with open(fb_data_path, "r", encoding="raw-unicode-escape") as posts:
    photos_json = json.loads(convert_encoding_meta(posts.read()))

## %% Extraire les photos non catégorisées du JSON
facebook_photos = photos_json['other_photos_v2']

## %% Créer un DataFrame à partir des photos extraites
facebook_photos_df = pd.DataFrame(facebook_photos)

## %% Filtrer les publications sans description
facebook_photos_df = facebook_photos_df[~facebook_photos_df['description'].isnull()]

## %% Ajouter des métadonnées au DataFrame
facebook_photos_df['index'] = "rs_facebook_posts"
facebook_photos_df['network'] = "Facebook"
facebook_photos_df['type'] = "posts"
facebook_photos_df['chemin'] = fb_data_path

## %% Renommer la colonne 'description' en 'texte'
facebook_photos_df.rename(columns={"description": "texte"}, inplace=True)

## %% Supprimer la colonne 'media_metadata'
del facebook_photos_df['media_metadata']

## %% Remplacer les valeurs NaN par des chaînes vides
facebook_photos_df.fillna(value="", inplace=True)

## %% Envoyer les données à la base de données
documents_to_database(facebook_photos_df)