import pandas as pd
import json
import os
from pathlib import Path

from utils.documents_to_database import documents_to_database
from utils.convert_encoding_meta import convert_encoding_meta

## %% Obtenir le répertoire du fichier courant
# Obtenir le répertoire du fichier courant
try:
    # Ceci fonctionnera lors de l'exécution en tant que script
    script_dir = Path(__file__).parent.parent
except NameError:
    # Ceci fonctionnera dans des environnements interactifs
    script_dir = Path().absolute()

project_root = script_dir
instagram_data_path = os.path.join(project_root, 'import_data', 'data', 'Instagram', 'content', 'posts_1.json')

## %% Lire et parser le fichier JSON des publications Instagram
with open(instagram_data_path, "r", encoding="raw-unicode-escape") as posts:
    posts_json = json.loads(convert_encoding_meta(posts.read()))

## %% Extraire et structurer les données des publications Instagram
posts_medias = []
for post in posts_json:
    medias = post['media']
    # S'il y a un seul média
    if len(medias) == 1:
        media = medias[0]
        posts_medias.append({
            "uri": [media["uri"]],
            "chemin": instagram_data_path,
            "index": "rs_instagram_content",
            "type": "content",
            "network": "Instagram",
            "texte": media["title"],
            "creation_timestamp": media["creation_timestamp"]})
    else:
        # S'il y a plusieurs médias,
        # on va itérer sur chacun des médias
        # pour récupérer les URI
        title = post['title']
        creation_timestamp = post['creation_timestamp']
        list_uris = []
        for media in medias:
            uri = media['uri']
            list_uris.append(uri)
        posts_medias.append({
            "uri": list_uris,
            "chemin": instagram_data_path,
            "index": "rs_instagram_content",
            "type": "posts",
            "network": "Instagram",
            "texte": title,
            "creation_timestamp": creation_timestamp})

## %% Créer un DataFrame à partir des données extraites
posts_medias_df = pd.DataFrame(posts_medias)

## %% Remplacer les valeurs NaN par des chaînes vides
posts_medias_df.fillna(value="", inplace=True)

## %% Supprimer les doublons basés sur le texte et la date de création
posts_medias_df.drop_duplicates(subset=['texte', 'creation_timestamp'], inplace=True)

## %% Filtrer les publications avec un texte vide
posts_medias_df = posts_medias_df[~posts_medias_df['texte'].str.strip().eq('')]

## %% Envoyer les données à la base de données
documents_to_database(posts_medias_df)