import pandas as pd
import json
import os
from pathlib import Path

from utils.documents_to_database import documents_to_database
from utils.convert_encoding_meta import convert_encoding_meta

## %% Obtenir le répertoire du fichier courant
# Obtenir le répertoire du fichier courant
try:
    # Ceci fonctionnera lors de l'exécution en tant que script
    script_dir = Path(__file__).parent.parent
except NameError:
    # Ceci fonctionnera dans des environnements interactifs
    script_dir = Path().absolute()

project_root = script_dir
instagram_data_path = os.path.join(project_root, 'import_data', 'data', 'Instagram', 'content', 'reels.json')

## %% Lire et parser le fichier JSON des reels Instagram
with open(instagram_data_path, "r", encoding="raw-unicode-escape") as posts:
    reels_json = json.loads(convert_encoding_meta(posts.read()))

## %% Extraire les données média des reels
ig_reels_media = [x['media'][0] for x in reels_json['ig_reels_media']]

## %% Créer un DataFrame à partir des données extraites
ig_reels_df = pd.DataFrame(ig_reels_media)

## %% Ajouter des colonnes supplémentaires au DataFrame
ig_reels_df['index'] = "rs_instagram_content"
ig_reels_df['type'] = "reels"
ig_reels_df['network'] = "Instagram"
ig_reels_df['chemin'] = instagram_data_path

## %% Renommer la colonne 'title' en 'texte'
ig_reels_df.rename(columns={"title": "texte"}, inplace=True)

## %% Supprimer les colonnes non nécessaires
del ig_reels_df['media_metadata']
del ig_reels_df['cross_post_source']
del ig_reels_df['dubbing_info']

## %% Remplacer les valeurs NaN par des chaînes vides
ig_reels_df.fillna(value="", inplace=True)

## %% Supprimer les doublons basés sur le texte et la date de création
ig_reels_df.drop_duplicates(subset=['texte', 'creation_timestamp'], inplace=True)

## %% Filtrer les reels avec un texte vide
ig_reels_df = ig_reels_df[~ig_reels_df['texte'].str.strip().eq('')]

## %% Envoyer les données à la base de données
documents_to_database(ig_reels_df)