import pandas as pd
import json
import os
from pathlib import Path

from utils.documents_to_database import documents_to_database
from utils.convert_encoding_meta import convert_encoding_meta

## %% Obtenir le répertoire du fichier courant
# Obtenir le répertoire du fichier courant
try:
    # Ceci fonctionnera lors de l'exécution en tant que script
    script_dir = Path(__file__).parent.parent
except NameError:
    # Ceci fonctionnera dans des environnements interactifs
    script_dir = Path().absolute()

project_root = script_dir
instagram_data_path = os.path.join(project_root, 'import_data', 'data', 'Instagram', 'content', 'stories.json')

## %% Lire et parser le fichier JSON des stories Instagram
with open(instagram_data_path, "r", encoding="raw-unicode-escape") as posts:
    stories_json = json.loads(convert_encoding_meta(posts.read()))

## %% Créer un DataFrame à partir des données des stories
ig_stories_df = pd.DataFrame(stories_json['ig_stories'])

## %% Ajouter des colonnes supplémentaires au DataFrame
ig_stories_df['index'] = "rs_instagram_content"
ig_stories_df['type'] = "stories"
ig_stories_df['network'] = "Instagram"
ig_stories_df['chemin'] = instagram_data_path

## %% Renommer la colonne 'title' en 'texte'
ig_stories_df.rename(columns={"title": "texte"}, inplace=True)

## %% Supprimer les colonnes non nécessaires
del ig_stories_df['media_metadata']
del ig_stories_df['cross_post_source']
del ig_stories_df['ai_stickers']
del ig_stories_df['dubbing_info']

## %% Remplacer les valeurs NaN par des chaînes vides
ig_stories_df.fillna(value="", inplace=True)

## %% Supprimer les doublons basés sur le texte et la date de création
ig_stories_df.drop_duplicates(subset=['texte', 'creation_timestamp'], inplace=True)

## %% Filtrer les stories avec un texte vide
ig_stories_df = ig_stories_df[~ig_stories_df['texte'].str.strip('\n').str.strip().eq('')]

## %% Envoyer les données à la base de données
documents_to_database(ig_stories_df)