import pandas as pd
import datetime

import os
from pathlib import Path

from utils.documents_to_database import documents_to_database

## %% Obtenir le répertoire du fichier courant
# Obtenir le répertoire du fichier courant
try:
    # Ceci fonctionnera lors de l'exécution en tant que script
    script_dir = Path(__file__).parent.parent
except NameError:
    # Ceci fonctionnera dans des environnements interactifs
    script_dir = Path().absolute()

project_root = script_dir
linkedin_data_path = os.path.join(project_root, 'import_data', 'data', 'LinkedIn', 'shares', 'Shares.csv')

raw_shares = pd.read_csv(linkedin_data_path)

## %% Ajouter des colonnes d'identification au DataFrame
raw_shares['index'] = "rs_linkedin_shares"
raw_shares['type'] = "posts"
raw_shares['network'] = "LinkedIn"
raw_shares['chemin'] = linkedin_data_path

## %% Convertir la date en timestamp et supprimer la colonne originale
raw_shares["creation_timestamp"] = raw_shares["Date"].apply(
    lambda x: int(datetime.datetime.fromisoformat(x).timestamp())
)
del raw_shares["Date"]

## %% Renommer les colonnes pour correspondre au format standard
raw_shares.rename(columns={"ShareLink": "uri", "ShareCommentary": "texte"}, inplace=True)

## %% Convertir la colonne 'texte' en type string
raw_shares["texte"] = raw_shares["texte"].apply(lambda x: str(x))

## %% Supprimer les colonnes non nécessaires
del raw_shares["SharedUrl"]
del raw_shares["MediaUrl"]
del raw_shares["Visibility"]

## %% Remplacer les valeurs NaN par des chaînes vides
raw_shares.fillna(value="", inplace=True)

## %% Supprimer les doublons basés sur le texte et la date de création
raw_shares.drop_duplicates(subset=['texte', 'creation_timestamp'], inplace=True)

## %% Filtrer les partages avec un texte vide
# Filtrer les textes vides
raw_shares = raw_shares[~raw_shares['texte'].str.strip('\n').str.strip().eq('')]

## %% Envoyer les données à la base de données
documents_to_database(raw_shares)